@@ -1,7 +1,7 @@
 package Tk::ProgressBar;
 
 use vars qw($VERSION);
-$VERSION = '4.011'; # was: sprintf '4.%03d', q$Revision: #10 $ =~ /\D(\d+)\s*$/;
+$VERSION = '4.014'; # was: sprintf '4.%03d', q$Revision: #10 $ =~ /\D(\d+)\s*$/;
 
 use Tk;
 use Tk::Canvas;
@@ -298,7 +298,7 @@ sub value {
 sub variable {
     my $c = shift;
     my $oldvarref = $c->{'-variable'};
-    my $oldval = $$oldvarref if $oldvarref;
+    my $oldval; $oldval = $$oldvarref if $oldvarref;
     if(@_) {
 	my $varref = shift;
         if ($oldvarref)
@@ -334,8 +334,8 @@ Tk::ProgressBar - A graphical progress bar
     use Tk::ProgressBar;
 
     $progress = $parent->ProgressBar(
-	-width => 200,
-	-length => 20,
+	-width => 20,
+	-length => 200,
         -anchor => 's',
 	-from => 0,
 	-to => 100,
@@ -450,12 +450,12 @@ full progress bar will be displayed. Defaults to 100.
 =item B<-variable>
 
 Specifies the reference to a scalar variable to link to the ProgressBar.
-Whenever the value of the variable changes, the ProgressBar will upate
+Whenever the value of the variable changes, the ProgressBar will update
 to reflect this value. (See also the B<value> method below.)
 
 =item B<-value>
 
-The can be used to set the current position of the progress bar
+This can be used to set the current position of the progress bar
 when used in conjunction with the standard C<configure>. It is
 usually recommended to use the B<value> method instead.
 
