@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkCanvArc.c,v 1.10 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkCanvArc.c,v 1.11 2003/02/09 07:48:22 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -82,9 +82,9 @@ typedef struct ArcItem  {
 
 static int	StyleParseProc _ANSI_ARGS_((
 		    ClientData clientData, Tcl_Interp *interp,
-		    Tk_Window tkwin, Arg value,
+		    Tk_Window tkwin, Tcl_Obj * value,
 		    char *widgRec, int offset));
-static Arg	StylePrintProc _ANSI_ARGS_((
+static Tcl_Obj *	StylePrintProc _ANSI_ARGS_((
 		    ClientData clientData, Tk_Window tkwin,
 		    char *widgRec, int offset,
 		    Tcl_FreeProc **freeProcPtr));
@@ -305,23 +305,10 @@ CreateArc(interp, canvas, itemPtr, objc, objv)
     Tcl_Obj *CONST objv[];		/* Arguments describing arc. */
 {
     ArcItem *arcPtr = (ArcItem *) itemPtr;
-    int i = 4;
+    int i;
 
-    if (objc == 1) {
-	i = 1;
-    } else if (objc > 1) {
-	char *arg = Tcl_GetString(objv[1]);
-	if ((arg[0] == '-') && (arg[1] >= 'a') && (arg[1] <= 'z')) {
-	    i = 1;
-	}
-    }
-
-    if (objc < i) {
-	Tcl_AppendResult(interp, "wrong # args: should be \"",
-		Tk_PathName(Tk_CanvasTkwin(canvas)), " create ",
-		itemPtr->typePtr->name, " x1 y1 x2 y2 ?options?\"",
-		(char *) NULL);
-	return TCL_ERROR;
+    if (objc == 0) {
+	panic("canvas did not pass any coords\n");
     }
 
     /*
@@ -350,10 +337,16 @@ CreateArc(interp, canvas, itemPtr, objc, objv)
      * Process the arguments to fill in the item record.
      */
 
-    if ((ArcCoords(interp, canvas, itemPtr, i, objv) != TCL_OK)) {
+    for (i = 1; i < objc; i++) {
+	char *arg = Tcl_GetString(objv[i]);
+	if ((arg[0] == '-') && (arg[1] >= 'a') && (arg[1] <= 'z')) {
+	    break;
+	}
+    }
+    if (ArcCoords(interp, canvas, itemPtr, i, objv) != TCL_OK) {
 	goto error;
     }
-    if (ConfigureArc(interp, canvas, itemPtr, objc-4, objv+4, 0) == TCL_OK) {
+    if (ConfigureArc(interp, canvas, itemPtr, objc-i, objv+i, 0) == TCL_OK) {
 	return TCL_OK;
     }
     error:
@@ -2055,7 +2048,7 @@ StyleParseProc(clientData, interp, tkwin, ovalue, widgRec, offset)
     ClientData clientData;		/* some flags.*/
     Tcl_Interp *interp;			/* Used for reporting errors. */
     Tk_Window tkwin;			/* Window containing canvas widget. */
-    Arg ovalue;				/* Value of option. */
+    Tcl_Obj * ovalue;				/* Value of option. */
     char *widgRec;			/* Pointer to record for item. */
     int offset;				/* Offset into item. */
 {
@@ -2115,7 +2108,7 @@ StyleParseProc(clientData, interp, tkwin, ovalue, widgRec, offset)
  *--------------------------------------------------------------
  */
 
-static Arg
+static Tcl_Obj *
 StylePrintProc(clientData, tkwin, widgRec, offset, freeProcPtr)
     ClientData clientData;		/* Ignored. */
     Tk_Window tkwin;			/* Ignored. */
@@ -2125,7 +2118,7 @@ StylePrintProc(clientData, tkwin, widgRec, offset, freeProcPtr)
 					 * information about how to reclaim
 					 * storage for return string. */
 {
-    Arg result = NULL;
+    Tcl_Obj * result = NULL;
     register Style *stylePtr = (Style *) (widgRec + offset);
 
     if (*stylePtr==ARC_STYLE) {
