@@ -169,7 +169,7 @@ static Tk_OptionSpec optionSpecs[] = {
 	TK_OPTION_NULL_OK, 0, 0},
     {TK_OPTION_STRING, "-text", "text", "Text",
 	DEF_MESSAGE_TEXT, -1, Tk_Offset(Message, string), 0, 0, 0},
-    {TK_OPTION_STRING, "-textvariable", "textVariable", "Variable",
+    {TK_OPTION_OBJ, "-textvariable", "textVariable", "Variable",
 	DEF_MESSAGE_TEXT_VARIABLE, -1, Tk_Offset(Message, textVarName),
 	TK_OPTION_NULL_OK, 0, 0},
     {TK_OPTION_PIXELS, "-width", "width", "Width",
@@ -187,7 +187,7 @@ static void		MessageCmdDeletedProc _ANSI_ARGS_((
 static void		MessageEventProc _ANSI_ARGS_((ClientData clientData,
 			    XEvent *eventPtr));
 static char *		MessageTextVarProc _ANSI_ARGS_((ClientData clientData,
-			    Tcl_Interp *interp, Var name1, 
+			    Tcl_Interp *interp, Var name1,
 			    CONST char *name2, int flags));
 static int		MessageWidgetObjCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int objc,
