@@ -19,32 +19,6 @@
 #include "tkInt.h"
 #include "tkText.h"
 
-/*
- * Information used for parsing tag configuration information:
- */
-
-static Tk_CustomOption stateOption = {
-    TkStateParseProc,
-    TkStatePrintProc, (ClientData) 2
-};
-
-/* The "-elide" is only provided for compatibility with TkMan 2.0,
- * but might be removed in the future. The option "-state" provides
- * the same functionality and is preferred.
- */
-
-static int	ElideParseProc _ANSI_ARGS_((ClientData clientData,
-		    Tcl_Interp *interp, Tk_Window tkwin,
-		    Arg value, char *widgRec, int offset));
-static Arg	ElidePrintProc _ANSI_ARGS_((ClientData clientData,
-		    Tk_Window tkwin, char *widgRec, int offset,
-		    Tcl_FreeProc **freeProcPtr));
-
-static Tk_CustomOption elideOption = {
-    ElideParseProc,
-    ElidePrintProc, (ClientData) 0
-};
-
 static Tk_ConfigSpec tagConfigSpecs[] = {
     {TK_CONFIG_BORDER, "-background", (char *) NULL, (char *) NULL,
 	(char *) NULL, Tk_Offset(TkTextTag, border), TK_CONFIG_NULL_OK},
@@ -53,7 +27,7 @@ static Tk_ConfigSpec tagConfigSpecs[] = {
     {TK_CONFIG_STRING, "-borderwidth", (char *) NULL, (char *) NULL,
 	"0", Tk_Offset(TkTextTag, bdString),
 	TK_CONFIG_DONT_SET_DEFAULT|TK_CONFIG_NULL_OK},
-    {TK_CONFIG_STRING, "-elide", (char *) NULL, (char *) NULL,
+    {TK_CONFIG_LANGARG, "-elide", (char *) NULL, (char *) NULL,
 	"0", Tk_Offset(TkTextTag, elideString),
 	TK_CONFIG_DONT_SET_DEFAULT|TK_CONFIG_NULL_OK},
     {TK_CONFIG_BITMAP, "-fgstipple", (char *) NULL, (char *) NULL,
@@ -83,9 +57,6 @@ static Tk_ConfigSpec tagConfigSpecs[] = {
 	(char *) NULL, Tk_Offset(TkTextTag, spacing2String), TK_CONFIG_NULL_OK},
     {TK_CONFIG_STRING, "-spacing3", (char *) NULL, (char *) NULL,
 	(char *) NULL, Tk_Offset(TkTextTag, spacing3String), TK_CONFIG_NULL_OK},
-    {TK_CONFIG_CUSTOM, "-state", (char *) NULL, (char *) NULL,
-	(char *) NULL, Tk_Offset(TkTextTag, state),
-	TK_CONFIG_NULL_OK, &stateOption},
     {TK_CONFIG_LANGARG, "-tabs", (char *) NULL, (char *) NULL,
 	(char *) NULL, Tk_Offset(TkTextTag, tabString), TK_CONFIG_NULL_OK},
     {TK_CONFIG_LANGARG, "-underline", (char *) NULL, (char *) NULL,
@@ -1465,93 +1436,3 @@ TkTextPickCurrent(textPtr, eventPtr)
 	ckfree((char *) copyArrayPtr);
     }
 }
-
-/*
- *--------------------------------------------------------------
- *
- * ElideParseProc --
- *
- *	This procedure is invoked during option processing to handle
- *	the "-elide" option. This option is an obsolete equivalent
- *	of the "-state" option. It is only added for compatibility
- *	with TkMan 2.0, but will be removed in the future.
- *
- * Results:
- *	A standard Tcl return value.
- *
- * Side effects:
- *	The state for a given item gets replaced by the state
- *	indicated in the value argument.
- *
- *--------------------------------------------------------------
- */
-
-static int
-ElideParseProc(clientData, interp, tkwin, value, widgRec, offset)
-    ClientData clientData;		/* some flags.*/
-    Tcl_Interp *interp;			/* Used for reporting errors. */
-    Tk_Window tkwin;			/* Window containing canvas widget. */
-    Arg value;				/* Value of option. */
-    char *widgRec;			/* Pointer to record for item. */
-    int offset;				/* Offset into item. */
-{
-    int b;
-    register Tk_State *statePtr = (Tk_State *) (widgRec + offset);
-    char *svalue = Tcl_GetString(value);
-
-    if(svalue == NULL || *svalue == 0) {
-	*statePtr = TK_STATE_NULL;
-	return TCL_OK;
-    }
-    if (Tcl_GetBooleanFromObj(interp, value, &b) != TCL_OK) {
-	*statePtr = TK_STATE_NULL;
-	return TCL_ERROR;
-    }
-    *statePtr = b?TK_STATE_HIDDEN:TK_STATE_NORMAL;
-    return TCL_OK;
-}
-/*
- *--------------------------------------------------------------
- *
- * ElidePrintProc --
- *
- *	This procedure is invoked by the Tk configuration code
- *	to produce a printable string for the "-elide"
- *	configuration option.
- *
- * Results:
- *	The return value is a string describing the state for
- *	the item referred to by "widgRec".  In addition, *freeProcPtr
- *	is filled in with the address of a procedure to call to free
- *	the result string when it's no longer needed (or NULL to
- *	indicate that the string doesn't need to be freed).
- *
- * Side effects:
- *	None.
- *
- *--------------------------------------------------------------
- */
-
-static Arg
-ElidePrintProc(clientData, tkwin, widgRec, offset, freeProcPtr)
-    ClientData clientData;		/* Ignored. */
-    Tk_Window tkwin;			/* Window containing text widget. */
-    char *widgRec;			/* Pointer to record for item. */
-    int offset;				/* Offset into item. */
-    Tcl_FreeProc **freeProcPtr;		/* Pointer to variable to fill in with
-					 * information about how to reclaim
-					 * storage for return string. */
-{
-    register Tk_State *statePtr = (Tk_State *) (widgRec + offset);
-
-    if (*statePtr==TK_STATE_HIDDEN) {
-	return Tcl_NewIntObj(1);
-    } else if (*statePtr==TK_STATE_NULL) {
-	return LangStringArg("");
-    } else {
-	return Tcl_NewIntObj(0);
-    }
-}
-
-
-
