@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclProc.c,v 1.41 2002/08/05 03:24:41 dgp Exp $
+ * RCS: @(#) $Id: tclProc.c,v 1.44.2.1 2003/07/18 23:35:39 dgp Exp $
  */
 
 #include "tclInt.h"
@@ -150,8 +150,9 @@ Tcl_ProcObjCmd(dummy, interp, objc, objv)
 
 
     /*
-     * Optimize for noop procs: if the argument list is just "args"
-     * and the body is empty, define a compileProc.
+     * Optimize for noop procs: if the body is not precompiled (like a TclPro
+     * procbody), and the argument list is just "args" and the body is empty,
+     * define a compileProc to compile a noop.
      *
      * Notes:
      *   - cannot be done for any argument list without having different
@@ -161,12 +162,15 @@ Tcl_ProcObjCmd(dummy, interp, objc, objv)
      *     are about to ignore ...
      *   - could be enhanced to handle also non-empty bodies that contain
      *     only comments; however, parsing the body will slow down the
-     *     compilation of all procs whose argument list is just _args_
-     */
+     *     compilation of all procs whose argument list is just _args_ */
+
+    if (objv[3]->typePtr == &tclProcBodyType) {
+	goto done;
+    }
 
     procArgs = Tcl_GetString(objv[2]);
 
-    while(*procArgs == ' ') {
+    while (*procArgs == ' ') {
 	procArgs++;
     }
 
@@ -184,7 +188,7 @@ Tcl_ProcObjCmd(dummy, interp, objc, objv)
 	 */
 
 	procBody = Tcl_GetString(objv[3]);
-	while(*procBody != '\0') {
+	while (*procBody != '\0') {
 	    if (!isspace(UCHAR(*procBody))) {
 		goto done;
 	    }
@@ -401,28 +405,32 @@ TclCreateProc(interp, nsPtr, procName, argsPtr, bodyPtr, procPtrPtr)
 	    p++;
 	}
 
-        if (precompiled) {
-            /*
-             * compare the parsed argument with the stored one
-             */
+	if (precompiled) {
+	    /*
+	     * Compare the parsed argument with the stored one.
+	     * For the flags, we and out VAR_UNDEFINED to support bridging
+	     * precompiled <= 8.3 code in 8.4 where this is now used as an
+	     * optimization indicator.	Yes, this is a hack. -- hobbs
+	     */
 
-            if ((localPtr->nameLength != nameLength)
-                    || (strcmp(localPtr->name, fieldValues[0]))
-                    || (localPtr->frameIndex != i)
-                    || (localPtr->flags != (VAR_SCALAR | VAR_ARGUMENT))
-                    || ((localPtr->defValuePtr == NULL)
-                            && (fieldCount == 2))
-                    || ((localPtr->defValuePtr != NULL)
-                            && (fieldCount != 2))) {
-                char buf[80 + TCL_INTEGER_SPACE];
-                sprintf(buf, "\": formal parameter %d is inconsistent with precompiled body",
-                        i);
-                Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
-                        "procedure \"", procName,
-                        buf, (char *) NULL);
-                ckfree((char *) fieldValues);
-                goto procError;
-            }
+	    if ((localPtr->nameLength != nameLength)
+		    || (strcmp(localPtr->name, fieldValues[0]))
+		    || (localPtr->frameIndex != i)
+		    || ((localPtr->flags & ~VAR_UNDEFINED)
+			    != (VAR_SCALAR | VAR_ARGUMENT))
+		    || ((localPtr->defValuePtr == NULL)
+			    && (fieldCount == 2))
+		    || ((localPtr->defValuePtr != NULL)
+			    && (fieldCount != 2))) {
+		char buf[80 + TCL_INTEGER_SPACE];
+		sprintf(buf, "\": formal parameter %d is inconsistent with precompiled body",
+			i);
+		Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+			"procedure \"", procName,
+			buf, (char *) NULL);
+		ckfree((char *) fieldValues);
+		goto procError;
+	    }
 
             /*
              * compare the default value if any
@@ -1221,6 +1229,14 @@ TclProcCompileProc(interp, procPtr, bodyPtr, nsPtr, description, procName)
  		    numChars = 50;
  		    ellipsis = "...";
  		}
+		while ( (procName[numChars] & 0xC0) == 0x80 ) {
+	            /*
+		     * Back up truncation point so that we don't truncate
+		     * in the middle of a multi-byte character (in UTF-8)
+		     */
+		    numChars--;
+		    ellipsis = "...";
+		}
  		sprintf(buf, "\n    (compiling %s \"%.*s%s\", line %d)",
  			description, numChars, procName, ellipsis,
  			interp->errorLine);
@@ -1289,7 +1305,7 @@ ProcessProcResultCode(interp, procName, nameLen, returnCode)
     if (returnCode == TCL_OK) {
 	return TCL_OK;
     }
-    if (returnCode > TCL_CONTINUE) {
+    if ((returnCode > TCL_CONTINUE) || (returnCode < TCL_OK)) {
 	return returnCode;
     }
     if (returnCode == TCL_RETURN) {
@@ -1305,6 +1321,14 @@ ProcessProcResultCode(interp, procName, nameLen, returnCode)
 	nameLen = 60;
 	ellipsis = "...";
     }
+    while ( (procName[nameLen] & 0xC0) == 0x80 ) {
+        /*
+	 * Back up truncation point so that we don't truncate in the
+	 * middle of a multi-byte character (in UTF-8)
+	 */
+	nameLen--;
+	ellipsis = "...";
+    }
     sprintf(msg, "\n    (procedure \"%.*s%s\" line %d)", nameLen, procName,
 	    ellipsis, iPtr->errorLine);
     Tcl_AddObjErrorInfo(interp, msg, -1);
