@@ -52,22 +52,8 @@ static TIX_DECLARE_SUBCMD(Tix_GrFormatBorder);
 static TIX_DECLARE_SUBCMD(Tix_GrFormatGrid);
 EXTERN TIX_DECLARE_SUBCMD(Tix_GrFormat);
 
-#ifdef ITCL_21
-
-/*
- * ITcl 2.1 changed the definition of the constants for Tk configuration,
- * e.g., TK_CONFIG_COLOR, etc. This problem doesn't appear in itcl 2.2.
- */
-typedef Tk_ConfigProc * CFG_TYPE;
-
-#else
-
-typedef int CFG_TYPE;
-
-#endif
-
 static int		Tix_GrSaveColor _ANSI_ARGS_((WidgetPtr wPtr,
-			    CFG_TYPE type, void * ptr));
+			    int type, void * ptr));
 static void	    	GetBlockPosn _ANSI_ARGS_((WidgetPtr wPtr, int x1,
 			    int y1, int x2, int y2, int * bx1, int * by1,
 			    int * bx2, int * by2));
@@ -499,16 +485,6 @@ Tix_GrFormatBorder(clientData, interp, argc, argv)
     GetBlockPosn(wPtr, info.x1, info.y1, info.x2, info.y2,
 	&bx1, &by1, &bx2, &by2);
 
-#if 0
-    /* now it works */
-#ifdef _WINDOWS
-    if (bx1 == 0 && bx2 == 0 && by1 == 0 && by2 == 0) {
-	/* some how this doesn't work in BC++ 4.5 */
-	goto done;
-    }
-#endif
-#endif
-
     for (i=bx1; i<=bx2; i+=(info.xon+info.xoff)) {
 	for (j=by1; j<=by2; j+=(info.yon+info.yoff)) {
 	    int _bx1, _by1, _bx2, _by2;
@@ -735,7 +711,7 @@ Tix_GrFormatGrid(clientData, interp, argc, argv)
 /* returns 1 if the caller can free the border/color */
 static int Tix_GrSaveColor(wPtr, type, ptr)
     WidgetPtr wPtr;
-    CFG_TYPE type;
+    int type;
     void * ptr;
 {
     Tk_3DBorder border = NULL;
