@@ -317,7 +317,7 @@ struct TixImageTextItem {
 	/*	 Text		  */
 	/*-------------------------*/
 
-    Arg text;		/* Show descriptive text */
+    Tcl_Obj * text;		/* Show descriptive text */
     size_t numChars;		/* Size of text */
     int textW, textH;
     int wrapLength;
@@ -377,7 +377,7 @@ struct TixTextItem {
 	/*	 Text		  */
 	/*-------------------------*/
 
-    Arg text;		/* Show descriptive text */
+    Tcl_Obj * text;		/* Show descriptive text */
     size_t numChars;		/* Size of text */
     int textW, textH;
     int underline;		/* Index of character to underline.  < 0 means
@@ -791,6 +791,13 @@ EXTERN void		Tix_WindowItemListRemove  _ANSI_ARGS_((
 
 typedef struct _TixpSubRegion TixpSubRegion;
 
+struct _TixpSubRegion {
+    Pixmap pixmap;
+    int origX, origY;
+    int x, y;
+    int width, height;
+};
+
 /*
  * Functions that should be used by Tix only. Functions prefixed by "Tix"
  * are generic functions that has one implementation for all platforms.
@@ -816,7 +823,7 @@ extern void		TixpEndSubRegionDraw _ANSI_ARGS_((Display *display,
 extern int		TixpSetWindowParent _ANSI_ARGS_((Tcl_Interp * interp,
 			    Tk_Window tkwin, Tk_Window newParent,
 			    int parentId));
-extern void		TixpStartSubRegionDraw _ANSI_ARGS_((Display *display,
+extern void		TixpStartSubRegionDraw _ANSI_ARGS_((Tix_DispData *ddPtr,
 			     Drawable drawable, GC gc,
 			     TixpSubRegion * subRegPtr, int origX,
 			     int origY, int x, int y, int width, int height,
