@@ -30,7 +30,7 @@ typedef struct ListEntry {
     struct ListEntry * next;
     Tix_DItem * iPtr;
     Tk_Uid state;
-    Arg data;			/* user data field */
+    Tcl_Obj * data;			/* user data field */
     int size[2];
     unsigned int selected : 1;
 } ListEntry;
