@@ -8,13 +8,12 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkWinDialog.c,v 1.29 2002/08/14 15:31:21 vincentdarley Exp $
+ * RCS: @(#) $Id: tkWinDialog.c,v 1.30.2.1 2003/07/18 19:51:35 hobbs Exp $
  *
  */
 
 #include "tkWinInt.h"
 #include "tkFileFilter.h"
-#undef Arg
 
 #ifndef __OPEN32__
 #include <commdlg.h>    /* includes common dialog functionality */
@@ -122,10 +121,10 @@ static const struct {int type; int btnIds[3];} allowedTypes[] = {
  * be retrieved with tk_get*File -multiple 1.  It must be allocated
  * on the stack, so make it large enough but not too large.  -- hobbs
  * The data is stored as <dir>\0<file1>\0<file2>\0...<fileN>\0\0.
- * MAX_PATH == 260 on Win2K/NT.
+ * MAX_PATH == 260 on Win2K/NT, so *40 is ~10K.
  */
 
-#define TK_MULTI_MAX_PATH	(MAX_PATH*20)
+#define TK_MULTI_MAX_PATH	(MAX_PATH*40)
 
 /*
  * The following structure is used to pass information between the directory
@@ -1474,7 +1473,7 @@ MakeFilter(interp, string, dsPtr)
     FileFilter *filterPtr;
 
     TkInitFileFilters(&flist);
-    if (TkGetFileFilters(interp, &flist, string, 1) != TCL_OK) {
+    if (TkGetFileFilters(interp, &flist, Tcl_NewStringObj(string,-1), 1) != TCL_OK) {
 	return TCL_ERROR;
     }
 
@@ -1670,8 +1669,6 @@ Tk_ChooseDirectoryObjCmd(clientData, interp, objc, objv)
     TCHAR saveDir[MAX_PATH];
     Tcl_DString titleString;	/* UTF Title */
     Tcl_DString initDirString;	/* Initial directory */
-    ThreadSpecificData *tsdPtr = (ThreadSpecificData *)
-	Tcl_GetThreadData(&dataKey, sizeof(ThreadSpecificData));
     static CONST char *optionStrings[] = {
         "-initialdir", "-mustexist",  "-parent",  "-title", (char *) NULL
     };
@@ -1919,7 +1916,7 @@ ChooseDirectoryValidateProc (
                     /*
                      * User HAS to select a valid directory.
                      */
-                    wsprintf(selDir, _T("Directory '%.200s' does not exist,\nplease select or enter an existing directory."), chooseDirSharedData->utfRetDir);
+                    wsprintf(selDir, TEXT("Directory '%.200s' does not exist,\nplease select or enter an existing directory."), chooseDirSharedData->utfRetDir);
                     MessageBox(NULL, selDir, NULL, MB_ICONEXCLAMATION|MB_OK);
                     return 1;
                 }
@@ -2448,7 +2445,8 @@ Tk_MessageBoxObjCmd(clientData, interp, objc, objv)
     HWND hWnd;
     char *message, *title;
     int defaultBtn, icon, type;
-    int i, oldMode, flags, winCode;
+    int i, oldMode, winCode;
+    UINT flags;
     Tcl_DString messageString, titleString;
     Tcl_Encoding unicodeEncoding = TkWinGetUnicodeEncoding();
     static CONST char *optionStrings[] = {
