@@ -5,13 +5,13 @@
 
 EXTERN int		LangCallCallback _ANSI_ARGS_((LangCallback *cb, int flags));
 EXTERN Tcl_Obj *	LangCallbackObj _ANSI_ARGS_((LangCallback *));
-EXTERN int		LangCmpCallback _ANSI_ARGS_((LangCallback *a,Arg b));
+EXTERN int		LangCmpCallback _ANSI_ARGS_((LangCallback *a,Tcl_Obj * b));
 EXTERN LangCallback *	LangCopyCallback _ANSI_ARGS_((LangCallback *));
 EXTERN void		LangDebug _ANSI_ARGS_((CONST char *fmt,...));
-EXTERN void LangExit _ANSI_ARGS_((int));
+EXTERN void		LangAsyncCheck _ANSI_ARGS_((void));
 EXTERN void		LangFreeCallback _ANSI_ARGS_((LangCallback *));
-EXTERN LangCallback *	LangMakeCallback _ANSI_ARGS_((Arg));
-EXTERN Arg		LangOldCallbackArg _ANSI_ARGS_((LangCallback *,char *,int));
+EXTERN LangCallback *	LangMakeCallback _ANSI_ARGS_((Tcl_Obj *));
+EXTERN Tcl_Obj *		LangOldCallbackArg _ANSI_ARGS_((LangCallback *,char *,int));
 EXTERN void		LangPushCallbackArgs _ANSI_ARGS_((LangCallback **svp));
 EXTERN long Lang_OSHandle _ANSI_ARGS_((int fd));
 EXTERN void		Tcl_AlertNotifier _ANSI_ARGS_((ClientData clientData));
